@@ -152,7 +152,7 @@ class ReplTheme(Theme):
     exit_kw: str = "bold green"
     exit_str: str = "cyan"
     greeting: str = "cyan"
-    addl_styles: dict = None
+    addl_styles: dict | None = None
 
     def __post_init__(self) -> None:
         styles = dict(vars(self))
@@ -166,48 +166,48 @@ class ReplTheme(Theme):
 class ReplBase:
     """Dataclass for CLI options"""
 
-    debug_enabled: bool = None
+    debug_enabled: bool | None = None
     """Debug mode enabled"""
 
-    title: str = None
+    title: str | None = None
     """Title of the CLI REPL Prompt"""
 
-    exit_keywords: list[str] = None
+    exit_keywords: list[str] | None = None
     """List of strings that cause the REPL to close, defaults to x, q, 
         exit, and quit"""
 
-    init_prompt: str | list[str] = None
+    init_prompt: str | list[str] | None = None
     """Prompt to display at startup"""
 
-    color_system: ColorSystem = None
+    color_system: ColorSystem | None = None
     """Color syste for the rich console"""
 
-    theme: ReplTheme | dict = None
+    theme: ReplTheme | dict | None = None
 
-    console: Console = None
+    console: Console | None = None
     """ Rich Console instance """
 
-    history: str = None
+    history: str | None = None
     """Path to the prompt history file"""
 
-    temp_file: str = None
+    temp_file: str | None = None
     """Path to prompt temporary file"""
 
-    style: dict | Style = None
+    style: dict | Style | None = None
     """Style for the prompt"""
 
-    ignore_case: bool = None
+    ignore_case: bool | None = None
     """Ignore case setting for the WordCompleter instance"""
 
-    commands: dict[str, ReplCommand] = None
+    commands: dict[str, ReplCommand] | None = None
     """Command dictionary for prompt_toolkit. Keys are command names,
         values are the corresponding description/help text"""
 
     docstring_format: str = "google"
 
-    parent: ReplBase | dict = None
+    parent: ReplBase | dict | None = None
 
-    session: PromptSession = None
+    session: PromptSession | None = None
 
     cmd_defs: dict[str, CommandMeta] = field(default_factory=dict)
 
@@ -496,10 +496,33 @@ class ReplBase:
             name = func.__name__
             self.add_command(name, func, help_txt=help_text)
 
-    def setup_cmds_2(self, *cmd_names: list[str], hyphenate: bool = True):
+    def setup_cmds_2(self, *cmd_names: str, hyphenate: bool = True):
         for name in cmd_names:
             self.gen_command(name, hyphenate=hyphenate)
 
+    def get_local_funcs(self, tgt_cls: type = None) -> list[str]:
+        """Retrieve a list of local functions for this class
+
+        Returns:
+            list[str]: List of function names
+        """
+
+        base_funcs = [
+            name
+            for name in dir(ReplBase)
+            if callable(getattr(ReplBase, name)) and not name.startswith("_")
+        ]
+
+        tgt_cls = tgt_cls or self.__class__
+
+        return [
+            name
+            for name in dir(tgt_cls)
+            if callable(getattr(tgt_cls, name))
+            and not name.startswith("_")
+            and name not in base_funcs
+        ]
+
     def warn(self, msg: str) -> None:
         """Print a message to the REPL preformatted as a warning"""
 
